.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

dbexample Documentation
=======================

This package is an example database that can be accessed by the databroker. It can be used for testing software
that built upon the data schemas in the databroker.

.. toctree::
   :maxdepth: 2

   installation
   usage
   changelog
   min_versions
